summaryrefslogtreecommitdiffstats
path: root/kjsembed/jssecuritypolicy.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 16:20:48 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 16:20:48 -0600
commite63beeb5bdb82987b1e00bc35178667786fbad48 (patch)
treeab77b6ac830b7944d5d1eb9ce8f81feb8fdab948 /kjsembed/jssecuritypolicy.h
parent67557a2b56c0678c22ab1b00c4fd0224c5e9ed99 (diff)
downloadtdebindings-e63beeb5bdb82987b1e00bc35178667786fbad48.tar.gz
tdebindings-e63beeb5bdb82987b1e00bc35178667786fbad48.zip
Fix incorrect conversion
Diffstat (limited to 'kjsembed/jssecuritypolicy.h')
-rw-r--r--kjsembed/jssecuritypolicy.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kjsembed/jssecuritypolicy.h b/kjsembed/jssecuritypolicy.h
index df39117e..a14f099c 100644
--- a/kjsembed/jssecuritypolicy.h
+++ b/kjsembed/jssecuritypolicy.h
@@ -36,7 +36,7 @@ class JSObjectProxy;
* A SecurityPolicy must define tests for the following situations:
* <ul>
* <li>Does this request come from the correct @ref KJS::Interpreter ?
* <li>Is the script allowed to access the specified TTQObject ?
* <li>Is the script allowed to access the specified property ?
* </ul>
* The various isAllowed() methods are called automatically by @ref JSObjectProxy
@@ -107,20 +107,20 @@ public:
virtual bool isInterpreterAllowed( const JSObjectProxy *prx, const KJS::Interpreter *interp ) const;
/**
* Returns true if scripts are allowed to see the specified TTQObject.
*/
- virtual bool isObjectAllowed( const JSObjectProxy *prx, const TTQObject *obj ) const;
+ virtual bool isObjectAllowed( const JSObjectProxy *prx, const TQObject *obj ) const;
/**
* Returns true if scripts are allowed to see the specified property.
*/
- virtual bool isPropertyAllowed( const JSObjectProxy *prx, const TTQObject *obj, const char *prop ) const;
+ virtual bool isPropertyAllowed( const JSObjectProxy *prx, const TQObject *obj, const char *prop ) const;
/**
* Returns true if scripts are allowed to create the specified child object.
*/
- virtual bool isCreateAllowed( const JSObjectProxy *prx, const TTQObject *parent,
- const TTQString &clazz, const TTQString &name ) const;
+ virtual bool isCreateAllowed( const JSObjectProxy *prx, const TQObject *parent,
+ const TQString &clazz, const TQString &name ) const;
/**
* Returns the default SecurityPolicy.
@@ -36,7 +36,7 @@ class JSObjectProxy;
* <ul>
* <li>Does this request come from the correct @ref KJS::Interpreter ?
- * <li>Is the script allowed to access the specified TTQObject ?
+ * <li>Is the script allowed to access the specified TQObject ?
* <li>Is the script allowed to access the specified property ?
* </ul>
@@ -107,20 +107,20 @@ public:
virtual bool isInterpreterAllowed( const JSObjectProxy *prx, const KJS::Interpreter *interp ) const;
/**
- * Returns true if scripts are allowed to see the specified TTQObject.
+ * Returns true if scripts are allowed to see the specified TQObject.
*/